# Generated by Django 4.2.6 on 2023-12-12 16:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('content_blocks', '0009_alter_contentblock_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentblockfield',
            name='text',
            field=models.TextField(blank=True),
        ),
    ]
